=== modified file 'drizzled/atomic/gcc_traits.h'
--- drizzled/atomic/gcc_traits.h	2009-03-04 02:48:12 +0000
+++ drizzled/atomic/gcc_traits.h	2009-03-30 18:17:18 +0000
@@ -20,7 +20,7 @@
 #ifndef DRIZZLED_ATOMIC_GCC_TRAITS_H
 #define DRIZZLED_ATOMIC_GCC_TRAITS_H
 
-namespace tbb {
+namespace drizzled {
 namespace internal {
 
 template<typename T, typename D>
@@ -80,6 +80,6 @@
 
 
 } /* namespace internal */
-} /* namespace tbb */
+} /* namespace drizzled */
 
 #endif /* DRIZZLED_ATOMIC_GCC_TRAITS_H */

=== modified file 'drizzled/atomic/pthread_traits.h'
--- drizzled/atomic/pthread_traits.h	2009-03-04 02:48:12 +0000
+++ drizzled/atomic/pthread_traits.h	2009-03-30 18:17:18 +0000
@@ -21,7 +21,7 @@
 #ifndef DRIZZLED_ATOMIC_PTHREAD_TRAITS_H
 #define DRIZZLED_ATOMIC_PTHREAD_TRAITS_H
 
-namespace tbb {
+namespace drizzled {
 
 namespace internal {
 
@@ -133,7 +133,7 @@
 
 
 } /* namespace internal */
-} /* namespace tbb */
+} /* namespace drizzled */
 
 
 #endif /* DRIZZLED_ATOMIC_PTHREAD_TRAITS_H */

=== modified file 'drizzled/atomics.h'
--- drizzled/atomics.h	2009-03-30 17:37:38 +0000
+++ drizzled/atomics.h	2009-03-30 18:17:18 +0000
@@ -23,6 +23,13 @@
 
 #if defined(HAVE_LIBTBB)
 # include <tbb/atomic.h>
+/* We're actually using the TBB interface directly, but we don't want to tie
+ * the code to a specific implementation. So suck the tbb:: stuff into the
+ * drizzled namespace
+ */
+namespace drizzled {
+  using namspace tbb;
+};
 #else
 
 # if defined(__SUNPRO_CC)
@@ -35,11 +42,13 @@
 #  define ATOMIC_TRAITS internal::pthread_traits
 # endif
 
-# include <pthread.h>
-# include <drizzled/atomic/pthread_traits.h>
-
-
-namespace tbb {
+# if (SIZEOF_SIZE_T >= SIZEOF_LONG_LONG) || (!defined(HAVE_GCC_ATOMIC_BUILTINS) || !defined(__SUNPRO_CC))
+#  include <pthread.h>
+#  include <drizzled/atomic/pthread_traits.h>
+# endif
+
+
+namespace drizzled {
 
 namespace internal {
 
@@ -138,7 +147,7 @@
 struct atomic {
 };
 
-#define __TBB_DECL_ATOMIC(T)                                            \
+#define __DRIZZLE_DECL_ATOMIC(T)                                        \
   template<> struct atomic<T>                                           \
   : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> > {                    \
     atomic<T>() : internal::atomic_impl<T,T,ATOMIC_TRAITS<T,T> >() {}   \
@@ -146,32 +155,33 @@
   };
 
 
-__TBB_DECL_ATOMIC(long)
-__TBB_DECL_ATOMIC(unsigned long)
-__TBB_DECL_ATOMIC(unsigned int)
-__TBB_DECL_ATOMIC(int)
-__TBB_DECL_ATOMIC(unsigned short)
-__TBB_DECL_ATOMIC(short)
-__TBB_DECL_ATOMIC(char)
-__TBB_DECL_ATOMIC(signed char)
-__TBB_DECL_ATOMIC(unsigned char)
-__TBB_DECL_ATOMIC(bool)
+__DRIZZLE_DECL_ATOMIC(long)
+__DRIZZLE_DECL_ATOMIC(unsigned long)
+__DRIZZLE_DECL_ATOMIC(unsigned int)
+__DRIZZLE_DECL_ATOMIC(int)
+__DRIZZLE_DECL_ATOMIC(unsigned short)
+__DRIZZLE_DECL_ATOMIC(short)
+__DRIZZLE_DECL_ATOMIC(char)
+__DRIZZLE_DECL_ATOMIC(signed char)
+__DRIZZLE_DECL_ATOMIC(unsigned char)
+__DRIZZLE_DECL_ATOMIC(bool)
 
 /* 32-bit platforms don't have a GCC atomic operation for 64-bit types,
  * so we'll use pthread locks to handler 64-bit types on that platforms
  */
 #  if SIZEOF_SIZE_T >= SIZEOF_LONG_LONG
-__TBB_DECL_ATOMIC(long long)
-__TBB_DECL_ATOMIC(unsigned long long)
+__DRIZZLE_DECL_ATOMIC(long long)
+__DRIZZLE_DECL_ATOMIC(unsigned long long)
 #  else
-#   define __TBB_DECL_ATOMIC64(T)                                            \
+#   define __DRIZZLE_DECL_ATOMIC64(T)                                   \
   template<> struct atomic<T>                                           \
-  : internal::atomic_impl<T,T,internal::pthread_traits<T,T> > {                    \
-    atomic<T>() : internal::atomic_impl<T,T,internal::pthread_traits<T,T> >() {}   \
+  : internal::atomic_impl<T,T,internal::pthread_traits<T,T> > {         \
+    atomic<T>()                                                         \
+      : internal::atomic_impl<T,T,internal::pthread_traits<T,T> >() {}  \
     T operator=( T rhs ) { return store_with_release(rhs); }            \
   };
-__TBB_DECL_ATOMIC64(long long)
-__TBB_DECL_ATOMIC64(unsigned long long)
+__DRIZZLE_DECL_ATOMIC64(long long)
+__DRIZZLE_DECL_ATOMIC64(unsigned long long)
 #  endif
 
 }

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-03-25 22:03:13 +0000
+++ drizzled/drizzled.cc	2009-03-30 18:17:18 +0000
@@ -425,7 +425,7 @@
   Number of currently active user connections. The variable is protected by
   LOCK_thread_count.
 */
-tbb::atomic<uint32_t> connection_count;
+drizzled::atomic<uint32_t> connection_count;
 
 /* Function declarations */
 

=== modified file 'drizzled/query_id.h'
--- drizzled/query_id.h	2009-03-23 00:03:45 +0000
+++ drizzled/query_id.h	2009-03-30 18:17:18 +0000
@@ -39,7 +39,7 @@
   query_id_t next();
 
 private:
-  tbb::atomic<uint64_t> the_query_id;
+  drizzled::atomic<uint64_t> the_query_id;
 
   Query_id();
   Query_id(Query_id const&);

=== modified file 'plugin/multi_thread/multi_thread.cc'
--- plugin/multi_thread/multi_thread.cc	2009-03-22 08:32:24 +0000
+++ plugin/multi_thread/multi_thread.cc	2009-03-30 18:17:18 +0000
@@ -30,7 +30,7 @@
 
 class Multi_thread_scheduler: public Scheduler
 {
-  tbb::atomic<uint32_t> thread_count;
+  drizzled::atomic<uint32_t> thread_count;
   pthread_attr_t multi_thread_attrib;
 
 public:

